"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _trimNewlines = require("trim-newlines");
var _style = require("./../../utils/style");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// Default theme with basic styles
const DEFAULT_THEME = {
  name: 'default',
  type: 'dark',
  colors: {
    'editor.foreground': '#000000',
    'editor.background': '#ffffff'
  },
  settings: [{
    settings: {
      foreground: '#000000',
      background: '#ffffff'
    }
  }]
};
async function createHighlighter(grammar) {
  const highlighter = await (0, _core.createHighlighterCore)({
    engine: (0, _engineJavascript.createJavaScriptRegexEngine)(),
    langs: grammar ? [grammar] : undefined
  });
  return highlighter;
}
const SyntaxHighlighter = ({
  code,
  language,
  theme,
  themeLoader,
  grammarDefinition,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [highlightedNodes, setHighlightedNodes] = (0, _react.useState)(null);
  const [error, setError] = (0, _react.useState)(null);
  const [loadedTheme, setLoadedTheme] = (0, _react.useState)(() => theme ?? DEFAULT_THEME);
  const [isLoading, setIsLoading] = (0, _react.useState)(true);
  (0, _react.useEffect)(() => {
    const loadResources = async () => {
      setIsLoading(true);
      try {
        // Load theme if themeLoader provided
        let themeToUse = theme ?? DEFAULT_THEME;
        if (themeLoader) {
          try {
            const loadedThemeModule = await themeLoader();
            themeToUse = loadedThemeModule.default;
          } catch (e) {
            console.warn('Failed to load theme:', e);
          }
        }
        setLoadedTheme(themeToUse);

        // Create highlighter with grammar
        const highlighter = await createHighlighter(grammarDefinition);

        // Highlight code
        const tokens = highlighter.codeToHast(code, {
          lang: language,
          theme: themeToUse
        });
        setHighlightedNodes(tokens.children || null);
        setError(null);
      } catch (err) {
        console.error('Syntax highlighting error:', err);
        setError(err instanceof Error ? err.message : 'Unknown error occurred');
        // Fallback to plain text
        setHighlightedNodes([{
          type: 'text',
          value: code
        }]);
      } finally {
        setIsLoading(false);
      }
    };
    loadResources();
  }, [code, language, theme, themeLoader, grammarDefinition]);

  // Create stylesheet from theme, using default theme as fallback
  const stylesheet = (0, _react.useMemo)(() => {
    try {
      return (0, _style.getRNStylesFromShikiStyle)(loadedTheme);
    } catch (e) {
      console.warn('Failed to create stylesheet:', e);
      return (0, _style.getRNStylesFromShikiStyle)(DEFAULT_THEME);
    }
  }, [loadedTheme]);
  const getStylesForNode = node => {
    const classes = node.properties?.className ?? [];
    return classes.map(c => stylesheet[c]).filter(Boolean);
  };
  const renderNode = (nodes, keyPrefix = 'row') => nodes.reduce((acc, node, index) => {
    const keyPrefixWithIndex = `${keyPrefix}_${index}`;
    if (node.children) {
      const styles = _reactNative.StyleSheet.flatten([textStyle, {
        color: stylesheet.shiki?.color
      }, ...getStylesForNode(node)]);
      acc.push(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: styles,
        children: renderNode(node.children, `${keyPrefixWithIndex}_child`)
      }, keyPrefixWithIndex));
    }
    if (node.value) {
      acc.push((0, _trimNewlines.trimNewlines)(String(node.value)));
    }
    return acc;
  }, []);
  if (isLoading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: containerStyle,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: textStyle,
        children: "Loading..."
      })
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: containerStyle,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: [textStyle, {
          color: 'red'
        }],
        children: ["Error rendering code:", error]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: textStyle,
        children: code
      })]
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    contentContainerStyle: [stylesheet.shiki, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: highlightedNodes && renderNode(highlightedNodes)
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map