"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createHighlighter = createHighlighter;
exports.processTokens = processTokens;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
  forgiving: true,
  simulation: true,
  cache: new Map()
});
async function initializeHighlighter(langs, themes) {
  try {
    return await (0, _core.createHighlighterCore)({
      langs,
      themes,
      engine
    });
  } catch (err) {
    console.error('Error initializing highlighter:', err);
    throw err;
  }
}
async function createHighlighter({
  langs,
  themes
}) {
  if (!langs?.length) {
    throw new Error('Please provide languages when creating a highlighter.');
  }
  try {
    const highlighter = await initializeHighlighter(langs, themes);
    return highlighter;
  } catch (error) {
    console.error('Failed to create highlighter:', error);
    throw error;
  }
}
function processTokens(tokens) {
  return tokens.map(token => ({
    content: token.content,
    color: token.color,
    fontStyle: token.fontStyle,
    offset: token.offset
  }));
}
//# sourceMappingURL=highlighter.js.map