"use strict";

import { useEffect, useState } from 'react';
import { createHighlighter } from '../syntax/highlighter';
export function useSyntaxHighlighter({
  text,
  language,
  languageId,
  theme
}) {
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState();
  const [isLoading, setIsLoading] = useState(true);
  useEffect(() => {
    let mounted = true;
    setIsLoading(true);
    async function highlight() {
      if (!text) {
        setIsLoading(false);
        setTokens([]);
        return;
      }
      try {
        const highlighter = await createHighlighter({
          langs: [language],
          themes: theme ? [theme] : []
        });
        const result = highlighter.codeToTokens(text, {
          lang: languageId,
          theme
        });
        if (mounted && result.tokens) {
          setTokens(result.tokens);
          setError(undefined);
        }
      } catch (err) {
        console.error('Highlighting error:', err);
        if (mounted) {
          setError(err instanceof Error ? err.message : 'Syntax highlighting failed');
          setTokens([]);
        }
      } finally {
        if (mounted) {
          setIsLoading(false);
        }
      }
    }
    highlight();
    return () => {
      mounted = false;
    };
  }, [text, language, languageId, theme]);
  return {
    tokens,
    error,
    isLoading
  };
}
//# sourceMappingURL=useSyntaxHighlighter.js.map