import type { ThemeRegistrationRaw } from '@shikijs/types'
import type { CSSProperties } from 'react'
import type { TextStyle } from 'react-native'
import transform, { type StyleTuple } from 'css-to-react-native'

export interface HighlighterStyleSheet {
  [key: string]: TextStyle
}
export type ReactStyle = Record<string, CSSProperties>

const ALLOWED_STYLE_PROPERTIES: Record<string, boolean> = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
}

export function getRNStylesFromShikiStyle(theme: ThemeRegistrationRaw): HighlighterStyleSheet {
  return Object.fromEntries(Object.entries(theme).map(([className, style]) => [className, cleanStyle(style)]))
}

export function cleanStyle(style: CSSProperties) {
  const styles = Object.entries(style)
    .filter(([key]) => ALLOWED_STYLE_PROPERTIES[key])
    .map<StyleTuple>(([key, value]) => [key, value])

  return transform(styles)
}
